Description Usage Arguments Author(s) Examples
View source: R/ideam2annual.R View source: R/ideam2annual.R
function for calculate monthly values of prepared data from DHIME (IDEAM, Colombia), apply to precipitation, minimum and maximum temperature.
1 | ideam2annual(x, param = NULL, na.rm = TRUE)
|
x |
dataframe of prepared data of a station from DHIME (IDEAM, Colombia) |
param |
default value is sum, sum is for precipitation and evaporation, mean for temperature and relative humidity, max for maximum values. |
na.rm |
default value is TRUE, TRUE for consider NA, FALSE for not consider NA. |
Geomar Perales Apaico
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.