ideam2monthly: function for calculate monthly values of prepared data from...

Description Usage Arguments Author(s) Examples

View source: R/ideam2monthly.R View source: R/ideam2monthly.R

Description

function for calculate monthly values of prepared data from DHIME (IDEAM, Colombia), apply to precipitation, minimum and maximum temperature.

Usage

1
ideam2monthly(x, param = NULL, na.rm = TRUE)

Arguments

x

dataframe of prepared data of a station from DHIME (IDEAM, Colombia).

param

default value is sum, sum is for precipitation and evaporation, mean for temperature and relative humidity, max for maximum values.

na.rm

default value is TRUE, TRUE for consider NA, FALSE for not consider NA.

Author(s)

Geomar Perales Apaico

Examples

1
2

GeomarPerales/ideamR documentation built on Dec. 17, 2021, 9:31 p.m.