ideamna: function for calculate days without information by month of...

Description Usage Arguments Author(s) Examples

View source: R/ideamna.R

Description

function for calculate days without information by month of prepared data of station from DHIME (IDEAM, Colombia), apply to precipitation, minimum and maximum temperature.

Usage

1

Arguments

x

dataframe of prepared data of a station from DHIME (IDEAM, Colombia).

type

default value is NULL, NULL is for days without information by month, inv is for days with information by month.

Author(s)

Geomar Perales Apaico

Examples

1
2

GeomarPerales/ideamR documentation built on Dec. 17, 2021, 9:31 p.m.