Description Usage Arguments Author(s) Examples
function for calculate days without information by month of prepared data of station from DHIME (IDEAM, Colombia), apply to precipitation, minimum and maximum temperature.
1 |
x |
dataframe of prepared data of a station from DHIME (IDEAM, Colombia). |
type |
default value is NULL, NULL is for days without information by month, inv is for days with information by month. |
Geomar Perales Apaico
1 2 | data <- ideamprep(Bucaramanga)
ideamna(data)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.